##  Configuring the TIME Classification Attribute for Fact Sheets
In meta model v4 workspaces, the TIME Classification field is a default attribute of the Application Fact Sheet.
In meta model v3 workspaces, admins can add the TIME attribute to the workspace through the Optional Feature and Early Access. To add the TIME attribute, do the following:
  1. Go to the Administration area.
  2. Open the Optional Feature & Early Access tab
  3. Click Activate on the Portfolio Strategy![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755630a7a4410148e02f6074580eb7b_LowRes.png)
  4. Now, when you open your Inventory and go to one of your Application Fact Sheets, you can see the new section that has been added.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b0ca07a441014a28ba3352cd5ff34_LowRes.png)
